@@ -4,15 +4,17 @@
 #include "helper.h"
 
 #include <QDebug>
-#include <QProcess>
 #include <QFileInfo>
+#include <QProcess>
+
+#include <chrono>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
-#include <string.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 // Append name to /dev/ and ensure it is a trustable block device.
 static QString nameToPath(const QString &name)
@@ -67,16 +69,15 @@ ActionReply SMARTHelper::smartctl(const QVariantMap &args)
     setenv("PATH", "/usr/sbin:/sbin", 1);
     QProcess p;
     // json=c is badly documented and means "gimme json but don't pretty print"
-    p.start(QStringLiteral("smartctl"),
-            { QStringLiteral("--all"), QStringLiteral("--json=c"), devicePath },
-            QProcess::ReadOnly);
+    p.start(QStringLiteral("smartctl"), {QStringLiteral("--all"), QStringLiteral("--json=c"), devicePath}, QProcess::ReadOnly);
     // Wait for 120 seconds + 5 seconds leeway.
     // This allows us to ideally let smartctl time out internally and still
     // construct a json blob if possible. The kernel ioctl timeout for nvme
     // apparently is 60 seconds and internal smartctl timeouts also largely
     // appear to be in that range but there may be more than one :|
     // https://bugs.kde.org/show_bug.cgi?id=428844
-    p.waitForFinished(125000);
+    using namespace std::chrono_literals;
+    p.waitForFinished(std::chrono::milliseconds(125s).count());
 
     ActionReply reply;
     reply.addData(QStringLiteral("exitCode"), p.exitCode());
